import React from 'react'
import { Link } from 'react-router-dom'

import { formatRecord } from '../../utils'

export default function RecordsCard (props) {
  const { records, sports } = props
  const recordsBySport = records.reduce((sportList, record) => {
      const sport = sports.find(s => s.id === record.sport_id)
      if (sportList[sport.label] === void 0) {
        sportList[sport.label] = {
          img: sport.img,
          records: [],
        }
      }
      sportList[sport.label].records.push(formatRecord(record))
      return sportList
  }, {})

  return (
    <div className="card activity-card">
      <div className="card-header">
        Personal records
      </div>
      <div className="card-body">
        {Object.keys(recordsBySport).map(sportLabel => (
          <table
            className="table table-borderless record-table"
            key={sportLabel}
          >
            <thead>
              <tr>
                <th colSpan="3">
                  <img
                    alt={`${sportLabel} logo`}
                    className="record-logo"
                    src={recordsBySport[sportLabel].img}
                  />
                  {sportLabel}
                </th>
              </tr>
            </thead>
            <tbody>
              {recordsBySport[sportLabel].records.map(rec => (
                <tr key={rec.id}>
                  <td>
                    {rec.record_type}
                  </td>
                  <td>
                   {rec.value}
                  </td>
                  <td>
                    <Link to={`/activities/${rec.activity_id}`}>
                      {rec.activity_date}
                    </Link>
                  </td>
                </tr>
              ))}
            </tbody>
          </table>
        ))}
      </div>
    </div>
  )
}

